@@ -1,5 +1,5 @@
 /*
-  $Id: icewm.cpp,v 1.47 2005/01/07 11:14:24 mlaurent Exp $
+  $Id: icewm.cpp 489039 2005-12-16 22:05:28Z giessl $
 
   Gallium-IceWM themeable KWin client
 
@@ -19,8 +19,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 
   -----------------------------------------------------------------------------
   This client loads most icewm 1.0.X pixmap themes, without taking into account
@@ -1453,8 +1453,10 @@ void IceWMClient::showEvent(QShowEvent *ev)
 
 void IceWMClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-	QRect r;
+	if( e->button() != LeftButton )
+		return;
 
+	QRect r;
 	if (titleBarOnTop)
 		r.setRect( borderSizeX, borderSizeY, width()-(2*borderSizeX), titleBarHeight);
 	else
@@ -1467,6 +1469,13 @@ void IceWMClient::mouseDoubleClickEvent( QMouseEvent * e )
 }
 
 
+void IceWMClient::wheelEvent(QWheelEvent *e)
+{
+	if (isSetShade() || QRect( 0, 0, width(), titleBarHeight ).contains( e->pos() ) )
+		titlebarMouseWheelOperation( e->delta());
+}
+
+
 // Called via Client class when the miniIcon() changes
 void IceWMClient::iconChange()
 {
@@ -1668,6 +1677,9 @@ bool IceWMClient::eventFilter( QObject* o, QEvent* e )
 	case QEvent::MouseButtonPress:
 		processMousePressEvent(static_cast< QMouseEvent* >( e ) );
 		return true;
+	case QEvent::Wheel:
+		wheelEvent( static_cast< QWheelEvent* >( e ));
+		return true;
 	default:
 		break;
 	}
