@@ -741,10 +741,16 @@ void NextClient::paintEvent( QPaintEvent* )
 
 void NextClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-    if (titlebar->geometry().contains( e->pos() ) )
+    if (e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
 	titlebarDblClickOperation();
 }
 
+void NextClient::wheelEvent( QWheelEvent * e )
+{
+    if (isSetShade() || QRect( 0, 0, width(), titleHeight ).contains( e->pos() ) )
+	titlebarMouseWheelOperation( e->delta());
+}
+
 void NextClient::showEvent(QShowEvent *)
 {
     widget()->repaint();
@@ -881,6 +887,9 @@ bool NextClient::eventFilter(QObject *o, QEvent *e)
     case QEvent::MouseButtonDblClick:
 	mouseDoubleClickEvent(static_cast< QMouseEvent* >( e ));
 	return true;
+    case QEvent::Wheel:
+	wheelEvent( static_cast< QWheelEvent* >( e ));
+	return true;
     case QEvent::MouseButtonPress:
 	processMousePressEvent(static_cast< QMouseEvent* >( e ));
 	return true;
